@@ -369,11 +369,10 @@ public:
     virtual void 		stop( IOService * 		provider );
 	virtual	IOReturn	message( UInt32 type, IOService * provider, void * argument = 0 );
 
-    OSMetaClassDeclareReservedUsed(IOUSBMassStorageClass,  1);
 	virtual IOReturn	HandlePowerOn( void );
 
-private:
 	// Space reserved for future expansion.
+    OSMetaClassDeclareReservedUnused( IOUSBMassStorageClass, 1 );
     OSMetaClassDeclareReservedUnused( IOUSBMassStorageClass, 2 );
     OSMetaClassDeclareReservedUnused( IOUSBMassStorageClass, 3 );
     OSMetaClassDeclareReservedUnused( IOUSBMassStorageClass, 4 );
